@@ -165,3 +165,47 @@ func TestFeatures(t *testing.T) {
 		t.Fatalf("loopback interface reported all features available")
 	}
 }
+
+func TestIdentity(t *testing.T) {
+	if testing.Short() {
+		return
+	}
+	intfs, err := net.Interfaces()
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	// we expected to have at least one success
+	empty := true
+	for _, intf := range intfs {
+		err := Identity(intf.Name, nil)
+		if err != nil {
+			continue
+		}
+		empty = false
+	}
+
+	if empty {
+		t.Fatal("Unable to identity any interface of this system.")
+	}
+}
+
+func BenchmarkStats(b *testing.B) {
+	intfs, err := net.Interfaces()
+	if err != nil {
+		b.Fatal(err)
+	}
+	for _, intf := range intfs {
+		if intf.Name == "lo" {
+			continue
+		}
+		b.Run(intf.Name, func(b *testing.B) {
+			for i := 0; i < b.N; i++ {
+				_, err := Stats(intf.Name)
+				if err != nil {
+					b.Fatal(err)
+				}
+			}
+		})
+	}
+}
